summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_sheetprint.h
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_sheetprint.h')
-rw-r--r--kspread/kspread_sheetprint.h135
1 files changed, 68 insertions, 67 deletions
diff --git a/kspread/kspread_sheetprint.h b/kspread/kspread_sheetprint.h
index b9b8fa94..99991f75 100644
--- a/kspread/kspread_sheetprint.h
+++ b/kspread/kspread_sheetprint.h
@@ -21,7 +21,7 @@
#ifndef __kspread_sheetprint_h__
#define __kspread_sheetprint_h__
-#include <qobject.h>
+#include <tqobject.h>
#include <koffice_export.h>
#include <KoUnit.h>
@@ -35,21 +35,22 @@ class Selection;
class PrintNewPageEntry;
class PrintObject;
-class KSPREAD_EXPORT SheetPrint : public QObject
+class KSPREAD_EXPORT SheetPrint : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
SheetPrint( Sheet *sheet );
~SheetPrint();
- QString saveOasisSheetStyleLayout( KoGenStyles &mainStyles );
+ TQString saveOasisSheetStyleLayout( KoGenStyles &mainStyles );
/**
* @return false if nothing to print.
*/
- bool print( QPainter &painter, KPrinter *_printer );
+ bool print( TQPainter &painter, KPrinter *_printer );
/**
* @return the prinsheet width of the paper in millimeters.
@@ -140,58 +141,58 @@ public:
/**
* @return the ascii name of the paper format ( like A4, Letter etc. )
*/
- QString paperFormatString()const;
+ TQString paperFormatString()const;
void setPaperFormat(KoFormat _format) {m_paperFormat=_format;}
void setPaperOrientation(KoOrientation _orient);
/**
- * Returns the page layout
+ * Returns the page tqlayout
*/
KoPageLayout paperLayout() const;
/**
- * Changes the paper layout and repaints the currently displayed Sheet.
+ * Changes the paper tqlayout and tqrepaints the currently displayed Sheet.
*/
void setPaperLayout( float _leftBorder, float _topBorder, float _rightBorder, float _bottomBoder,
KoFormat _paper, KoOrientation orientation );
/**
* A convenience function using a QString as paper format and orientation.
*/
void setPaperLayout( float _leftBorder, float _topBorder, float _rightBorder, float _bottomBoder,
- const QString& _paper, const QString& _orientation );
+ const TQString& _paper, const TQString& _orientation );
- QString headLeft( int _p, const QString &_t )const { if ( m_headLeft.isNull() ) return "";
+ TQString headLeft( int _p, const TQString &_t )const { if ( m_headLeft.isNull() ) return "";
return completeHeading( m_headLeft, _p, _t ); }
- QString headMid( int _p, const QString &_t )const { if ( m_headMid.isNull() ) return "";
+ TQString headMid( int _p, const TQString &_t )const { if ( m_headMid.isNull() ) return "";
return completeHeading( m_headMid, _p, _t ); }
- QString headRight( int _p, const QString &_t )const { if ( m_headRight.isNull() ) return "";
+ TQString headRight( int _p, const TQString &_t )const { if ( m_headRight.isNull() ) return "";
return completeHeading( m_headRight, _p, _t ); }
- QString footLeft( int _p, const QString &_t )const { if ( m_footLeft.isNull() ) return "";
+ TQString footLeft( int _p, const TQString &_t )const { if ( m_footLeft.isNull() ) return "";
return completeHeading( m_footLeft, _p, _t ); }
- QString footMid( int _p, const QString &_t )const { if ( m_footMid.isNull() ) return "";
+ TQString footMid( int _p, const TQString &_t )const { if ( m_footMid.isNull() ) return "";
return completeHeading( m_footMid, _p, _t ); }
- QString footRight( int _p, const QString &_t )const { if ( m_footRight.isNull() ) return "";
+ TQString footRight( int _p, const TQString &_t )const { if ( m_footRight.isNull() ) return "";
return completeHeading( m_footRight, _p, _t ); }
- QString headLeft()const { if ( m_headLeft.isNull() ) return ""; return m_headLeft; }
- QString headMid()const { if ( m_headMid.isNull() ) return ""; return m_headMid; }
- QString headRight()const { if ( m_headRight.isNull() ) return ""; return m_headRight; }
- QString footLeft()const { if ( m_footLeft.isNull() ) return ""; return m_footLeft; }
- QString footMid()const { if ( m_footMid.isNull() ) return ""; return m_footMid; }
- QString footRight()const { if ( m_footRight.isNull() ) return ""; return m_footRight; }
+ TQString headLeft()const { if ( m_headLeft.isNull() ) return ""; return m_headLeft; }
+ TQString headMid()const { if ( m_headMid.isNull() ) return ""; return m_headMid; }
+ TQString headRight()const { if ( m_headRight.isNull() ) return ""; return m_headRight; }
+ TQString footLeft()const { if ( m_footLeft.isNull() ) return ""; return m_footLeft; }
+ TQString footMid()const { if ( m_footMid.isNull() ) return ""; return m_footMid; }
+ TQString footRight()const { if ( m_footRight.isNull() ) return ""; return m_footRight; }
/**
* Returns the print range.
- * Returns ( QPoint (1, 1), QPoint(KS_colMax, KS_rowMax) ) if nothing is defined
+ * Returns ( TQPoint (1, 1), TQPoint(KS_colMax, KS_rowMax) ) if nothing is defined
*/
- QRect printRange() const { return m_printRange; }
+ TQRect printRange() const { return m_printRange; }
/**
* Sets the print range.
- * Set it to ( QPoint (1, 1), QPoint(KS_colMax, KS_rowMax) ) to undefine it
+ * Set it to ( TQPoint (1, 1), TQPoint(KS_colMax, KS_rowMax) ) to undefine it
*/
- void setPrintRange( const QRect &_printRange );
+ void setPrintRange( const TQRect &_printRange );
/**
* Return the page limit in X direction.
@@ -231,27 +232,27 @@ public:
/**
* Returns the columns, which are printed on each page.
* Returns QPair (0, 0) if nothing is defined
*/
- QPair<int, int> printRepeatColumns() const { return m_printRepeatColumns; }
+ TQPair<int, int> printRepeatColumns() const { return m_printRepeatColumns; }
/**
* Sets the columns to be printed on each page.
* Only the x-values of the points are used
* Set it to QPair (0, 0) to undefine it
*/
- void setPrintRepeatColumns( QPair<int, int> _printRepeatColumns );
+ void setPrintRepeatColumns( TQPair<int, int> _printRepeatColumns );
/**
* Returns the rows, which are printed on each page.
* Returns QPair (0, 0) if nothing is defined
*/
- QPair<int, int> printRepeatRows() const { return m_printRepeatRows; }
+ TQPair<int, int> printRepeatRows() const { return m_printRepeatRows; }
/**
* Sets the rows to be printed on each page.
* Only the y-values of the points are used
* Set it to QPair (0, 0) to undefine it
*/
- void setPrintRepeatRows( QPair<int, int> _printRepeatRows );
+ void setPrintRepeatRows( TQPair<int, int> _printRepeatRows );
/**
* Tests whether _column is the first column of a new page. In this
@@ -289,19 +290,19 @@ public:
/**
* Replaces in _text all _search text parts by _replace text parts.
* Included is a test to not change if _search == _replace.
* The arguments should not include neither the beginning "<" nor the leading ">", this is already
* included internally.
*/
- void replaceHeadFootLineMacro ( QString &_text, const QString &_search, const QString &_replace );
+ void replaceHeadFootLineMacro ( TQString &_text, const TQString &_search, const TQString &_tqreplace );
/**
* Replaces in _text all page macros by the i18n-version of the macros
*/
- QString localizeHeadFootLine ( const QString &_text );
+ TQString localizeHeadFootLine ( const TQString &_text );
/**
* Replaces in _text all i18n-versions of the page macros by the internal version of the macros
*/
- QString delocalizeHeadFootLine ( const QString &_text );
+ TQString delocalizeHeadFootLine ( const TQString &_text );
/**
* Returns the head and foot line of the print out
@@ -311,8 +312,8 @@ public:
/**
* Sets the head and foot line of the print out
*/
- void setHeadFootLine( const QString &_headl, const QString &_headm, const QString &_headr,
- const QString &_footl, const QString &_footm, const QString &_footr );
+ void setHeadFootLine( const TQString &_headl, const TQString &_headm, const TQString &_headr,
+ const TQString &_footl, const TQString &_footm, const TQString &_footr );
/**
* Returns, if the grid shall be shown on printouts
@@ -425,7 +426,7 @@ public:
/**
* Checks wether the page has content to print
*/
- bool pageNeedsPrinting( QRect& page_range );
+ bool pageNeedsPrinting( TQRect& page_range );
signals:
void sig_updateView( Sheet *_sheet );
@@ -441,29 +442,29 @@ private:
*
* @return the last vertical line which was printed plus one.
*
* @param _page_range QRect defines a rectangle of cells which should be
* painted to the device 'prn'.
*
* @param view KoRect defines the sourrounding rectangle which is
* the printing frame.
*
* @param _childOffset KoPoint used to calculate the correct position of
- * children, if there are repeated columns/rows.
+ * tqchildren, if there are repeated columns/rows.
*/
- void printPage( QPainter &_painter, const QRect& page_range,
+ void printPage( TQPainter &_painter, const TQRect& page_range,
const KoRect& view, const KoPoint _childOffset );
/**
* Prints a rect of cells defined by printRect at the position topLeft.
*/
- void printRect( QPainter &painter, const KoPoint& topLeft,
- const QRect& printRect, const KoRect& view,
- QRegion &clipRegion );
+ void printRect( TQPainter &painter, const KoPoint& topLeft,
+ const TQRect& printRect, const KoRect& view,
+ TQRegion &clipRegion );
/**
* Prints the header and footer on a page
*/
- void printHeaderFooter( QPainter &painter, int pageNo );
+ void printHeaderFooter( TQPainter &painter, int pageNo );
/**
* Looks at @ref #m_paperFormat and calculates @ref #m_paperWidth and @ref #m_paperHeight.
@@ -473,12 +474,12 @@ private:
/**
* Returns the iterator for the column in the newPage list for columns
*/
- QValueList<PrintNewPageEntry>::iterator findNewPageColumn( int col );
+ TQValueList<PrintNewPageEntry>::iterator findNewPageColumn( int col );
/**
* Returns the iterator for the row in the newPage list for rows
*/
- QValueList<PrintNewPageEntry>::iterator findNewPageRow( int row );
+ TQValueList<PrintNewPageEntry>::iterator findNewPageRow( int row );
/**
* Replaces macros like <name>, <file>, <date> etc. in the string and
@@ -487,23 +488,23 @@ private:
* @param _page is the page number for which the heading is produced.
* @param _Sheet is the name of the Sheet for which we generate the headings.
*/
- QString completeHeading( const QString &_data, int _page, const QString &_sheet ) const ;
+ TQString completeHeading( const TQString &_data, int _page, const TQString &_sheet ) const ;
/**
* Returns a rect, which contains the cols and rows to be printed.
- * It respects the printrange and the children
+ * It respects the printrange and the tqchildren
*/
- QRect cellsPrintRange();
+ TQRect cellsPrintRange();
/**
* Returns the numbers of pages in x direction
*/
- int pagesX( const QRect& cellsPrintRange );
+ int pagesX( const TQRect& cellsPrintRange );
/**
* Returns the numbers of pages in y direction
*/
- int pagesY( const QRect& cellsPrintRange );
+ int pagesY( const TQRect& cellsPrintRange );
/**
* The orientation of the paper.
@@ -544,32 +545,32 @@ private:
* Header string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_headLeft;
+ TQString m_headLeft;
/**
* Header string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_headRight;
+ TQString m_headRight;
/**
* Header string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_headMid;
+ TQString m_headMid;
/**
* Footer string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_footLeft;
+ TQString m_footLeft;
/**
* Footer string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_footRight;
+ TQString m_footRight;
/**
* Footer string. The string may contains makros. That means
* it has to be processed before printing.
*/
- QString m_footMid;
+ TQString m_footMid;
/**
* Number of total pages, only calculated during printing
@@ -579,17 +580,17 @@ private:
/**
* Defined prinsheet area
*/
- QRect m_printRange;
+ TQRect m_printRange;
/**
* Repeated columns on printout
*/
- QPair<int, int> m_printRepeatColumns;
+ TQPair<int, int> m_printRepeatColumns;
/**
* Repeated rows on printout
*/
- QPair<int, int> m_printRepeatRows;
+ TQPair<int, int> m_printRepeatRows;
/**
* Show the grid when making printout
@@ -633,12 +634,12 @@ private:
/**
* Stores the new page columns
*/
- QValueList<PrintNewPageEntry> m_lnewPageListX;
+ TQValueList<PrintNewPageEntry> m_lnewPageListX;
/**
* Stores the new page columns
*/
- QValueList<PrintNewPageEntry> m_lnewPageListY;
+ TQValueList<PrintNewPageEntry> m_lnewPageListY;
/**
* Stores internally the maximum column that was checked already
@@ -665,7 +666,7 @@ private:
*/
int m_iPageLimitY;
- QValueList<PrintObject*> m_printObjects;
+ TQValueList<PrintObject*> m_printObjects;
};
@@ -709,7 +710,7 @@ class PrintObject
PrintObject() : obj(0), p(0) {}
EmbeddedObject *obj;
- QPixmap *p;
+ TQPixmap *p;
};
} // namespace KSpread
@@ -140,58 +141,58 @@ public:
KoFormat _paper, KoOrientation orientation );
/**
- * A convenience function using a QString as paper format and orientation.
+ * A convenience function using a TQString as paper format and orientation.
*/
void setPaperLayout( float _leftBorder, float _topBorder, float _rightBorder, float _bottomBoder,
@@ -231,27 +232,27 @@ public:
/**
* Returns the columns, which are printed on each page.
- * Returns QPair (0, 0) if nothing is defined
+ * Returns TQPair (0, 0) if nothing is defined
*/
@@ -231,27 +232,27 @@ public:
* Sets the columns to be printed on each page.
* Only the x-values of the points are used
- * Set it to QPair (0, 0) to undefine it
+ * Set it to TQPair (0, 0) to undefine it
*/
@@ -231,27 +232,27 @@ public:
/**
* Returns the rows, which are printed on each page.
- * Returns QPair (0, 0) if nothing is defined
+ * Returns TQPair (0, 0) if nothing is defined
*/
@@ -231,27 +232,27 @@ public:
* Sets the rows to be printed on each page.
* Only the y-values of the points are used
- * Set it to QPair (0, 0) to undefine it
+ * Set it to TQPair (0, 0) to undefine it
*/
@@ -289,19 +290,19 @@ public:
/**
* Replaces in _text all _search text parts by _replace text parts.
- * Included is a test to not change if _search == _replace.
+ * Included is a test to not change if _search == _tqreplace.
* The arguments should not include neither the beginning "<" nor the leading ">", this is already
* included internally.
@@ -441,29 +442,29 @@ private:
* @return the last vertical line which was printed plus one.
*
- * @param _page_range QRect defines a rectangle of cells which should be
+ * @param _page_range TQRect defines a rectangle of cells which should be
* painted to the device 'prn'.
*